### 快速开始

PDFMathTranslate 是一个强大的 PDF 翻译工具。您可以通过多种方式安装和使用此工具。

---

### 如何安装？

1. [**Windows EXE**](./INSTALLATION_winexe.md) <small>推荐用于 Windows</small>
2. [**Docker**](./INSTALLATION_docker.md) <small>推荐用于 Linux</small>
3. [**uv** (一个 Python 包管理器)](./INSTALLATION_uv.md) <small>推荐用于 macOS</small>

---

### 如何使用？

1. [使用 **WebUI**](./USAGE_webui.md)
2. [使用 **Zotero 插件**](https://github.com/guaguastandup/zotero-pdf2zh) (第三方程序)
3. [使用 **命令行**](./USAGE_commandline.md)